package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Apr 14, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
README
¶
Subcmd

subcmd is very simple sub commands dispatcher.
Documentation
¶
Main represents entry point of a sub-command
Main2 represents entry point of a sub-command
type Subcmds map[string]interface{}
Subcmds represents sub-commands table. This should has Main, Main2 or
Subcmds as values.
Run parses args and executes one of sub-commands.
RunWithName parses args and executes one of sub-commands with name of
flag.FlagSet which passed to Main2 entry points.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.